run("../includes/tools/clearAll.js");

// Input of Parameters is done using a XML file: Prefab Brug.xml

// const Span = 15;
// var Angle = 10;
Angle = Angle * Math.PI / 180;
// const Width = 7;
// const NumberSupports = 8;
const WidthperBeam = Width / NumberSupports;
// const SupportOffset = 0.5;
// const BridgeThickness = 0.6;


// setup standard for combination wizard
general.current_standard_for_combination_wizard = general.NATIONAL_ANNEX_AND_EDITION_EN_1990_NEN_2019_11;
general.current_standard_for_load_wizard = general.NATIONAL_ANNEX_AND_EDITION_EN_1991_NEN_2020_08;
// general.current_standard_for_steel_design = general.NATIONAL_ANNEX_AND_EDITION_EN_1993_NEN_2016_12;
// general.current_standard_for_steel_joint_design = general.NATIONAL_ANNEX_AND_EDITION_EN_1993_NEN_2016_12;
// general.current_standard_for_concrete_design = general.NATIONAL_ANNEX_AND_EDITION_EN_1992_NEN_2020_02;
// general.current_standard_for_timber_design = general.NATIONAL_ANNEX_AND_EDITION_EN_1995_NEN_2014_06;
// general.current_standard_for_aluminum_design = general.NATIONAL_ANNEX_AND_EDITION_EN_1999_NEN_2014_01;

STEEL_DESIGN.setActive(false);
CONCRETE_DESIGN.setActive(false);
TIMBER_DESIGN.setActive(false);
ALUMINUM_DESIGN.setActive(false);
STEEL_JOINTS.setActive(false);

// create topology
// create two initial nodes
Node(undefined, 0, 0, 0, "Oorsprong");
Node(undefined, Math.sin(Angle) * Span, Span, 0);

// generate the rest of the nodes
for (var i = 1; i < NumberSupports+1; i++) {
    var dx = WidthperBeam * i;
    Node(undefined, dx , 0, 0);
    Node(undefined, dx + Math.sin(Angle) * Span, Span, 0);
    Node(undefined, dx + SupportOffset * Math.sin(Angle) - WidthperBeam * 0.5, SupportOffset * Math.cos(Angle), 0);
    Node(undefined, dx + (Span - SupportOffset) * Math.sin(Angle) - WidthperBeam * 0.5, Span - SupportOffset * Math.cos(Angle), 0);
}

// create first line
Line(undefined, [1, 2]);
Line(undefined, [1, 3]);
Line(undefined, [2, 4]);

for (var i = 0; i < NumberSupports; i++) {
    var delta = 4 * i;
    if (i < (NumberSupports - 1)) {
        Line(undefined, [3 + delta, 4 + delta]);
        Line(undefined, [3 + delta, 7 + delta]);
        Line(undefined, [4 + delta, 8 + delta]);
    }
    else {
        Line(undefined, [3 + delta, 4 + delta]);
    }
}

Material(undefined, "C35/45 | EN 1992-1-1:2004/A1:2014");
Material(undefined, "B500S(B) | EN 1992-1-1:2004/A1:2014");

// create surface

var th = new Thickness();
th.Uniform(1, "Dikte Betonnen Prefab Brug", 1, [BridgeThickness]);
thickness = 1;

Surface(undefined, "1-4", thickness);

for (var i = 1; i < NumberSupports; i++) {
    var delta = 1+ 3 * i;
    var linebegin = delta;
    var lineend = 3 + delta;    
    var surfacestring = linebegin + '-' + lineend;
    Surface(undefined, surfacestring, thickness);
 }

// create nodalsupport
var list = [];
for (var i = 0; i < NumberSupports; i++) {
    list.push(5 + i * 4);
    list.push(6 + i * 4);
}
var nodal_support = new NodalSupport(undefined, list);
nodal_support.Hinged();

// create resultbeams
// create section for the resultbeam
var section = Section(undefined, 'CIRCLE_M1 0.02', 1);

for (var i = 1; i < NumberSupports+1; i++) {
    var delta = 4 * i;
    var memberbegin = 1 + delta;
    var memberend = 2 + delta; 
    var list = [];
    list.push(memberbegin);
    list.push(memberend);

    Member(undefined, list);
    member.section_start = section;
    member.type = 10; // resultbeam type
    member.result_beam_integrate_stresses_and_forces = 3; // integrate stresses from included objects
    member.result_beam_include_all_surfaces = false;
    member.result_beam_include_surfaces = i;
}


var SASGeometricallyLinear = new StaticAnalysisSettings().GeometricallyLinear(1);

// create load case and two member loads
var load_case = new LoadCase().StaticAnalysis(1, "Eigen Gewicht", SASGeometricallyLinear.Settings.no, "ACTION_CATEGORY_PERMANENT_G", [true, 0, 0, 1.0]);
